summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--docs/constants.md2
-rw-r--r--lib/Controller/RoomController.php4
-rw-r--r--openapi-full.json2
-rw-r--r--openapi.json2
-rw-r--r--tests/integration/features/bootstrap/FeatureContext.php4
-rw-r--r--tests/integration/features/federation/invite.feature16
6 files changed, 16 insertions, 14 deletions
diff --git a/docs/constants.md b/docs/constants.md
index de8c7925c..5a7520e33 100644
--- a/docs/constants.md
+++ b/docs/constants.md
@@ -84,6 +84,7 @@
### Attendee types
* `users` - Logged-in users
+* `federated_users` - Federated users invited by their CloudID
* `groups` - Groups
* `circles` - [Circle from the Circles app](https://github.com/nextcloud/circles)
* `guests` - Guest without a login
@@ -111,6 +112,7 @@
* `bots` - Used by bots, commands (actor-id is the used `/command`) and the changelog conversation (actor-id is `changelog`)
* `bridged` - Users whose messages are bridged in by the [Matterbridge integration](matterbridge.md)
* `deleted_users` - Former logged-in users that got deleted (actor id is hardcoded to `deleted_users` and the display name is empty)
+* `federated_users` - Federated users
### Session states
* `0` - Inactive (Notifications should still be sent, even though the user has this session in the room)
diff --git a/openapi-full.json b/openapi-full.json
index ddc1a7847..b67ab7be6 100644
--- a/openapi-full.json
+++ b/openapi-full.json
@@ -11642,7 +11642,7 @@
"groups",
"circles",
"emails",
- "remotes",
+ "federated_users",
"phones"
]
}
diff --git a/openapi.json b/openapi.json
index 3ec324787..810548805 100644
--- a/openapi.json
+++ b/openapi.json
@@ -11747,7 +11747,7 @@
"groups",
"circles",
"emails",
- "remotes",
+ "federated_users",
"phones"
]
}
diff --git a/tests/integration/features/federation/invite.feature b/tests/integration/features/federation/invite.feature
index 9c325228b..dd01b72dc 100644
--- a/tests/integration/features/federation/invite.feature
+++ b/tests/integration/features/federation/invite.feature
@@ -9,7 +9,7 @@ Feature: federation/invite
Given user "participant1" creates room "room" (v4)
| roomType | 3 |
| roomName | room |
- And user "participant1" adds remote "participant2" to room "room" with 501 (v4)
+ And user "participant1" adds federated_user "participant2" to room "room" with 501 (v4)
When user "participant1" sees the following attendees in room "room" with 200 (v4)
| actorType | actorId | participantType |
| users | participant1 | 1 |
@@ -20,7 +20,7 @@ Feature: federation/invite
Given user "participant1" creates room "room" (v4)
| roomType | 3 |
| roomName | room |
- And user "participant1" adds remote "invalid-user" to room "room" with 404 (v4)
+ And user "participant1" adds federated_user "invalid-user" to room "room" with 404 (v4)
When user "participant1" sees the following attendees in room "room" with 200 (v4)
| actorType | actorId | participantType |
| users | participant1 | 1 |
@@ -31,7 +31,7 @@ Feature: federation/invite
Given user "participant1" creates room "room" (v4)
| roomType | 3 |
| roomName | room |
- And user "participant1" adds remote "participant2" to room "room" with 200 (v4)
+ And user "participant1" adds federated_user "participant2" to room "room" with 200 (v4)
When user "participant1" sees the following attendees in room "room" with 200 (v4)
| actorType | actorId | participantType |
| users | participant1 | 1 |
@@ -40,7 +40,7 @@ Feature: federation/invite
| room | actorType | actorId | systemMessage | message | messageParameters |
| room | users | participant1 | federated_user_added | You invited {federated_user} | {"actor":{"type":"user","id":"participant1","name":"participant1-displayname"},"federated_user":{"type":"user","id":"participant2","name":"participant2@localhost:8180","server":"http:\/\/localhost:8180"}} |
| room | users | participant1 | conversation_created | You created the conversation | {"actor":{"type":"user","id":"participant1","name":"participant1-displayname"}} |
- And user "participant1" adds remote "participant2" to room "room" with 200 (v4)
+ And user "participant1" adds federated_user "participant2" to room "room" with 200 (v4)
When user "participant1" sees the following attendees in room "room" with 200 (v4)
| actorType | actorId | participantType |
| users | participant1 | 1 |
@@ -93,7 +93,7 @@ Feature: federation/invite
Given user "participant1" creates room "room" (v4)
| roomType | 3 |
| roomName | room |
- And user "participant1" adds remote "participant2" to room "room" with 200 (v4)
+ And user "participant1" adds federated_user "participant2" to room "room" with 200 (v4)
When user "participant1" sees the following attendees in room "room" with 200 (v4)
| actorType | actorId | participantType |
| users | participant1 | 1 |
@@ -127,7 +127,7 @@ Feature: federation/invite
Given user "participant1" creates room "room" (v4)
| roomType | 3 |
| roomName | room |
- And user "participant1" adds remote "participant2" to room "room" with 200 (v4)
+ And user "participant1" adds federated_user "participant2" to room "room" with 200 (v4)
When user "participant1" sees the following attendees in room "room" with 200 (v4)
| actorType | actorId | participantType |
| users | participant1 | 1 |
@@ -162,7 +162,7 @@ Feature: federation/invite
Given user "participant1" creates room "room" (v4)
| roomType | 2 |
| roomName | room |
- And user "participant1" adds remote "participant2" to room "room" with 200 (v4)
+ And user "participant1" adds federated_user "participant2" to room "room" with 200 (v4)
And user "participant2" has the following invitations (v1)
| remoteServerUrl | remoteToken | state | inviterCloudId | inviterDisplayName |
| LOCAL | room | 0 | participant1@http://localhost:8080 | participant1-displayname |
@@ -188,7 +188,7 @@ Feature: federation/invite
Given user "participant1" creates room "room" (v4)
| roomType | 2 |
| roomName | room |
- And user "participant1" adds remote "participant2" to room "room" with 200 (v4)
+ And user "participant1" adds federated_user "participant2" to room "room" with 200 (v4)
And user "participant2" has the following invitations (v1)
| remoteServerUrl | remoteToken | state | inviterCloudId | inviterDisplayName |
| LOCAL | room | 0 | participant1@http://localhost:8080 | participant1-displayname |
diff --git a/lib/Controller/RoomController.php b/lib/Controller/RoomController.php
index 9a1abc01c..5c7419bfd 100644
--- a/lib/Controller/RoomController.php
+++ b/lib/Controller/RoomController.php
@@ -1026,7 +1026,7 @@ class RoomController extends AEnvironmentAwareController {
* Add a participant to a room
*
* @param string $newParticipant New participant
* @param 'users'|'groups'|'circles'|'emails'|'remotes'|'phones' $source Source of the participant
* @return DataResponse<Http::STATUS_OK, array{type: int}|array<empty>, array{}>|DataResponse<Http::STATUS_NOT_FOUND|Http::STATUS_NOT_IMPLEMENTED, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error?: string}, array{}>
*
* 200: Participant successfully added
@@ -1114,7 +1114,7 @@ class RoomController extends AEnvironmentAwareController {
}
return new DataResponse($data);
- } elseif ($source === 'remotes') {
+ } elseif ($source === 'federated_users') {
if (!$this->talkConfig->isFederationEnabled()) {
return new DataResponse([], Http::STATUS_NOT_IMPLEMENTED);
}
@@ -1026,7 +1026,7 @@ class RoomController extends AEnvironmentAwareController {
*
* @param string $newParticipant New participant
- * @param 'users'|'groups'|'circles'|'emails'|'remotes'|'phones' $source Source of the participant
+ * @param 'users'|'groups'|'circles'|'emails'|'federated_users'|'phones' $source Source of the participant
* @return DataResponse<Http::STATUS_OK, array{type: int}|array<empty>, array{}>|DataResponse<Http::STATUS_NOT_FOUND|Http::STATUS_NOT_IMPLEMENTED, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error?: string}, array{}>
*
diff --git a/tests/integration/features/bootstrap/FeatureContext.php b/tests/integration/features/bootstrap/FeatureContext.php
index c7fe82313..5d8739404 100644
--- a/tests/integration/features/bootstrap/FeatureContext.php
+++ b/tests/integration/features/bootstrap/FeatureContext.php
@@ -1662,7 +1662,7 @@ class FeatureContext implements Context, SnippetAcceptingContext {
}
/**
* @Then /^user "([^"]*)" adds (user|group|email|circle|remote|phone) "([^"]*)" to room "([^"]*)" with (\d+) \((v4)\)$/
*
* @param string $user
* @param string $newType
@@ -1674,7 +1674,7 @@ class FeatureContext implements Context, SnippetAcceptingContext {
public function userAddAttendeeToRoom(string $user, string $newType, string $newId, string $identifier, int $statusCode, string $apiVersion): void {
$this->setCurrentUser($user);
- if ($newType === 'remote') {
+ if ($newType === 'federated_user') {
$newId .= '@' . $this->baseRemoteUrl;
}
@@ -1662,7 +1662,7 @@ class FeatureContext implements Context, SnippetAcceptingContext {
}
/**
- * @Then /^user "([^"]*)" adds (user|group|email|circle|remote|phone) "([^"]*)" to room "([^"]*)" with (\d+) \((v4)\)$/
+ * @Then /^user "([^"]*)" adds (user|group|email|circle|federated_user|phone) "([^"]*)" to room "([^"]*)" with (\d+) \((v4)\)$/
*
* @param string $user